==> me-1.0.0.tar.gz: lib/functions/create/create_file.dart <==
import 'dart:io';

import 'package:path/path.dart';

import '../../core/structure.dart';
import '../../samples/interface/sample_interface.dart';
import '../../utils/logger/log_utils.dart';
import '../../utils/pubspec_utils.dart';
import '../sorter_imports/sort.dart';

File createFile({
  required String name,
  required String command,
  required Sample sample,
  String? folderName,
}) {
  final fileModel = Structure.feature(
    name,
    folderName: folderName ?? '',
    wrapperFolder: folderName != null,
  );
  var path = '${fileModel.path}_$command.dart';
  sample.path = path;
  return sample.create();
}

File writeFile(
  String path,
  String content, {
  bool overwrite = false,
  bool logger = true,
}) {
  var file = File(Structure.replaceAsExpected(path: path));

  if (!file.existsSync() || overwrite) {
    try {
      content = sortImports(
        content,
        filePath: path,
      );
    } on Exception catch (_) {
      if (file.existsSync()) {
        'The ${file.path} is not a valid dart file.';
      }
      rethrow;
    }
    var separatorFileType = PubspecUtils.separatorFileType!;
    if (separatorFileType.isNotEmpty) {
      file = file.existsSync()
          ? file =
              file.renameSync(replacePathTypeSeparator(path, separatorFileType))
          : File(replacePathTypeSeparator(path, separatorFileType));
    }

    file.createSync(recursive: true);
    file.writeAsStringSync(content);

    if (logger) {
      LogService.success(
          'File: ${basename(file.path)} created successfully at path: ${file.path}');
    }
  }
  return file;
}

String replacePathTypeSeparator(String path, String separator) {
  if (separator.isNotEmpty) {
    var index = path.indexOf(RegExp(r'controller.dart|model.dart|provider.dart|'
        'binding.dart|view.dart|screen.dart|widget.dart|repository.dart'));
    if (index != -1) {
      var chars = path.split('');
      index--;
      chars.removeAt(index);
      if (separator.length > 1) {
        chars.insert(index, separator[0]);
      } else {
        chars.insert(index, separator);
      }
      return chars.join();
    }
  }

  return path;
}

==> me-1.0.2.tar.gz: lib/functions/create/create_file.dart <==
import 'dart:io';

import 'package:path/path.dart';

import '../../core/structure.dart';
import '../../samples/interface/sample_interface.dart';
import '../../utils/logger/log_utils.dart';
import '../../utils/pubspec_utils.dart';
import '../sorter_imports/sort.dart';

File createFile({
  required String path,
  required String name,
  required String command,
  required Sample sample,
  String? folderName,
}) {
  final fileModel = Structure.feature(
    name,
    folderName: folderName ?? '',
    wrapperFolder: folderName != null,
  );
  String fullPath = '$path${fileModel.path}_$command.dart';
  sample.path = fullPath;
  return sample.create();
}

File writeFile(
  String path,
  String content, {
  bool overwrite = false,
  bool logger = true,
}) {
  var file = File(Structure.replaceAsExpected(path: path));

  if (!file.existsSync() || overwrite) {
    try {
      content = sortImports(
        content,
        filePath: path,
      );
    } on Exception catch (_) {
      if (file.existsSync()) {
        'The ${file.path} is not a valid dart file.';
      }
      rethrow;
    }
    var separatorFileType = PubspecUtils.separatorFileType!;
    if (separatorFileType.isNotEmpty) {
      file = file.existsSync()
          ? file =
              file.renameSync(replacePathTypeSeparator(path, separatorFileType))
          : File(replacePathTypeSeparator(path, separatorFileType));
    }

    file.createSync(recursive: true);
    file.writeAsStringSync(content);

    if (logger) {
      LogService.success(
          'File: ${basename(file.path)} created successfully at path: ${file.path}');
    }
  }
  return file;
}

String replacePathTypeSeparator(String path, String separator) {
  if (separator.isNotEmpty) {
    var index = path.indexOf(RegExp(r'controller.dart|model.dart|provider.dart|'
        'binding.dart|view.dart|screen.dart|widget.dart|repository.dart'));
    if (index != -1) {
      var chars = path.split('');
      index--;
      chars.removeAt(index);
      if (separator.length > 1) {
        chars.insert(index, separator[0]);
      } else {
        chars.insert(index, separator);
      }
      return chars.join();
    }
  }

  return path;
}
